==> rustc_1.85.0+dfsg3.orig.tar.xz: rustc-1.85.0-src/src/tools/clippy/book/src/SUMMARY.md <==
# Summary

[Introduction](README.md)

- [Installation](installation.md)
- [Usage](usage.md)
- [Configuration](configuration.md)
    - [Lint Configuration](lint_configuration.md)
- [Clippy's Lints](lints.md)
- [Attributes for Crate Authors](attribs.md)
- [Continuous Integration](continuous_integration/README.md)
    - [GitHub Actions](continuous_integration/github_actions.md)
    - [GitLab CI](continuous_integration/gitlab.md)
    - [Travis CI](continuous_integration/travis.md)
- [Development](development/README.md)
    - [Basics](development/basics.md)
    - [Adding Lints](development/adding_lints.md)
    - [Defining Lints](development/defining_lints.md)
    - [Writing tests](development/writing_tests.md)
    - [Lint Passes](development/lint_passes.md)
    - [Emitting lints](development/emitting_lints.md)
    - [Type Checking](development/type_checking.md)
    - [Trait Checking](development/trait_checking.md)
    - [Method Checking](development/method_checking.md)
    - [Macro Expansions](development/macro_expansions.md)
    - [Common Tools](development/common_tools_writing_lints.md)
    - [Infrastructure](development/infrastructure/README.md)
        - [Syncing changes between Clippy and rust-lang/rust](development/infrastructure/sync.md)
        - [Backporting Changes](development/infrastructure/backport.md)
        - [Updating the Changelog](development/infrastructure/changelog_update.md)
        - [Release a New Version](development/infrastructure/release.md)
        - [The Clippy Book](development/infrastructure/book.md)
    - [Proposals](development/proposals/README.md)
        - [Roadmap 2021](development/proposals/roadmap-2021.md)
        - [Syntax Tree Patterns](development/proposals/syntax-tree-patterns.md)
    - [The Team](development/the_team.md)

==> rustc_1.90.0+dfsg1.orig.tar.xz: rustc-1.90.0-src/src/tools/clippy/book/src/SUMMARY.md <==
# Summary

[Introduction](README.md)

- [Installation](installation.md)
- [Usage](usage.md)
- [Configuration](configuration.md)
    - [Lint Configuration](lint_configuration.md)
- [Clippy's Lints](lints.md)
- [Attributes for Crate Authors](attribs.md)
- [Continuous Integration](continuous_integration/README.md)
    - [GitHub Actions](continuous_integration/github_actions.md)
    - [GitLab CI](continuous_integration/gitlab.md)
    - [Travis CI](continuous_integration/travis.md)
- [Development](development/README.md)
    - [IMPORTANT: FEATURE FREEZE](development/feature_freeze.md)
    - [Basics](development/basics.md)
    - [Adding Lints](development/adding_lints.md)
    - [Defining Lints](development/defining_lints.md)
    - [Writing tests](development/writing_tests.md)
    - [Lint Passes](development/lint_passes.md)
    - [Emitting lints](development/emitting_lints.md)
    - [Type Checking](development/type_checking.md)
    - [Trait Checking](development/trait_checking.md)
    - [Method Checking](development/method_checking.md)
    - [Macro Expansions](development/macro_expansions.md)
    - [Common Tools](development/common_tools_writing_lints.md)
    - [Infrastructure](development/infrastructure/README.md)
        - [Syncing changes between Clippy and rust-lang/rust](development/infrastructure/sync.md)
        - [Backporting Changes](development/infrastructure/backport.md)
        - [Updating the Changelog](development/infrastructure/changelog_update.md)
        - [Release a New Version](development/infrastructure/release.md)
        - [The Clippy Book](development/infrastructure/book.md)
        - [Benchmarking Clippy](development/infrastructure/benchmarking.md)
    - [Proposals](development/proposals/README.md)
        - [Roadmap 2021](development/proposals/roadmap-2021.md)
        - [Syntax Tree Patterns](development/proposals/syntax-tree-patterns.md)
    - [The Team](development/the_team.md)
